ClassificationMetric
====================

.. currentmodule:: pykeen.metrics

.. autoclass:: ClassificationMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ClassificationMetric.binarize
      ~ClassificationMetric.closed_expectation
      ~ClassificationMetric.closed_variance
      ~ClassificationMetric.key
      ~ClassificationMetric.supports_weights
      ~ClassificationMetric.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~ClassificationMetric.extra_repr
      ~ClassificationMetric.get_description
      ~ClassificationMetric.get_link
      ~ClassificationMetric.get_range
      ~ClassificationMetric.iter_extra_repr
      ~ClassificationMetric.score

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: key
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: extra_repr
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: iter_extra_repr
   .. automethod:: score
